#!/usr/bin/env node

// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

// Load logger first so it can initialize and hook into debug
var logger = require('apiconnect-cli-logger');
var path = require('path');
var pkg = require('../package.json');
var checkLicense = require('../lib/license');

checkLicense()
  .then(processCmd);

function processCmd(data) {
  var cliPlugins = require('apiconnect-cli-plugins');
  var loadPlugins = cliPlugins.pluginLoader.loadPlugins;
  var buildCli = cliPlugins.buildCli;
  cliPlugins.init(path.dirname(__dirname));

  return loadPlugins().then(function(plugins) {
    var cmd = buildCli(pkg, plugins, {
      agreements: {
      },
    });
    return cmd(process.argv);
  }).then(function() {
    logger.debug('Command completed succesfully');
    return logger.exit(0);
  }).catch(function(err) {
    logger.debug('Command completed with error');
    logger.debug(err.message);
    logger.debug(err.stack);
    return logger.exit(err.exitCode ? err.exitCode : 1);
  });
}
