// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

var fs = require('fs');
var os = require('os');
var path = require('path');

function mktmpdir() {
  var mkdirp = require('mkdirp');
  var tmpdir = path.join(os.tmpdir(), Math.random() + '-' + (+new Date()));
  return mkdirp(tmpdir);
}
exports.mktmpdir = mktmpdir;

function getConfigDir(createDir) {
  if (typeof createDir === 'undefined') {
    createDir = true;
  }
  var os = require('os');
  var path = require('path');
  var env = process.env;
  var home = env.HOME;
  var user = env.LOGNAME || env.USER || env.LNAME || env.USERNAME;
  var homedir;
  if (process.platform === 'win32') {
    homedir = env.USERPROFILE || env.HOMEDRIVE + env.HOMEPATH || home || null;
  }
  if (process.platform === 'darwin') {
    homedir = home || (user ? '/Users/' + user : null);
  }
  if (process.platform === 'linux') {
    homedir = home || (process.getuid() === 0 ? '/root' : (user ? '/home/' + user : null));
  }
  var userDir = typeof os.homedir === 'function' ? os.homedir() : homedir;
  var configDir = process.env.APIC_CONFIG_PATH || path.resolve(userDir, '.apiconnect');
  if (createDir) {
    var mkdirp = require('mkdirp');
    mkdirp.sync(configDir);
  }
  return configDir;
}
exports.getConfigDir = getConfigDir;

function rmdir(p) {
  var files = [];
  fs.accessSync(p, fs.F_OK);
  files = fs.readdirSync(p);
  files.forEach(function(file, index) {
    var cp = p + '/' + file;
    if (fs.lstatSync(cp).isDirectory()) {
      rmdir(cp);
    } else {
      fs.unlinkSync(cp);
    }
  });
  fs.rmdirSync(p);
}
exports.rmdir = rmdir;
